@@ -115,7 +115,7 @@ validate_v4addr (char *addr)
 	y = 0;
 	for (x = 0; x < 4; x++) {
 		z = 0;
-		bzero ((char *) buf, 16);
+		safe_bzero (buf);
 		while (addr[y] != '.' && y < strlen (addr)) {
 			buf[z] = addr[y];
 			y++;
@@ -177,7 +177,7 @@ validate_netmask (char *in_addr)
 	if (x == 1)
 		return 3;
 
-	bzero ((char *) addr, 16);
+	safe_bzero (addr);
 	if (strstr (in_addr, "/")) {
 		x = 0;
 		while (in_addr[x] != '/' && x < 15) {
@@ -185,7 +185,7 @@ validate_netmask (char *in_addr)
 			x++;
 		}
 	} else {
-		strncpy (addr, in_addr, 16);
+		safe_strncpy (addr, in_addr);
 	}
 
 	/*
@@ -311,7 +311,7 @@ quadtonum (char *quad, u_int32_t * num)
 	if (!validate_v4addr (quad))
 		return -1;
 
-	bzero ((char *) buf, 128);
+	safe_bzero (buf);
 	x = 0;
 	while (quad[x] != '.') {
 		buf[x] = quad[x];
@@ -324,7 +324,7 @@ quadtonum (char *quad, u_int32_t * num)
 		if (z > 255 || z < 0)
 			return -1;
 		*num = *num | (z << (8 * (3 - y)));
-		bzero ((char *) buf, 128);
+		safe_bzero (buf);
 		z = 0;
 		while (quad[x] != '.' && quad[x] != '\0' && x < strlen (quad)) {
 			buf[z] = quad[x];
@@ -345,8 +345,8 @@ numtoquad (u_int32_t num)
 
 	for (x = 0; x < 4; x++)
 		a[x] = num >> (8 * (3 - x)) & 0xff;
-	bzero ((char *) quad, 17);
-	snprintf (quad, 16, "%d.%d.%d.%d", a[0], a[1], a[2], a[3]);
+	safe_bzero (quad);
+	safe_snprintf (quad, "%d.%d.%d.%d", a[0], a[1], a[2], a[3]);
 
 	return quad;
 }
@@ -357,7 +357,7 @@ numtobitmap (u_int32_t num)
 	static char bitmap[36];
 	int x, y, z;
 
-	bzero ((char *) bitmap, 36);
+	safe_bzero (bitmap);
 	y = 1;
 	z = 0;
 	for (x = 0; x < 32; x++) {
@@ -384,8 +384,8 @@ parse_addr (struct if_info *ifi)
 	char *s_find;
 	int x, y, z;
 
-	bzero ((char *) buf, 128);
-	bzero ((char *) buf2, 128);
+	safe_bzero (buf);
+	safe_bzero (buf2);
 	ifi->v4ad.n_nmaskbits = 0;
 
 	/*
@@ -507,9 +507,9 @@ get_addrv4 (struct if_info *ifi)
 		return -2;
 
 	/*
-	 * network class, class remark and classfull netmask
+	 * network class, class remark and classful netmask
 	 */
-	bzero ((char *) ifi->v4ad.class_remark, 64);
+	safe_bzero (ifi->v4ad.class_remark);
 	x = ifi->v4ad.n_haddr >> 24;
 	ifi->v4ad.n_cnaddr = 0;
 	if (!(x & 0x80)) {
@@ -526,22 +526,22 @@ get_addrv4 (struct if_info *ifi)
 	}
 	if ((x & 0xf0) == 0xe0) {
 		ifi->v4ad.class = 'D';
-		snprintf (ifi->v4ad.class_remark, 64, " (multicast network)");
+		safe_snprintf (ifi->v4ad.class_remark, " (multicast network)");
 		ifi->v4ad.n_cnmask = ifi->v4ad.n_nmask;
 	}
 	if ((x & 0xf8) == 0xf0) {
 		ifi->v4ad.class = 'E';
-		snprintf (ifi->v4ad.class_remark, 64,
+		safe_snprintf (ifi->v4ad.class_remark,
 			  " (reserved for future use)");
 		ifi->v4ad.n_cnmask = ifi->v4ad.n_nmask;
 	}
 	if (ifi->v4ad.class == '\0') {
 		ifi->v4ad.n_cnmask = ifi->v4ad.n_nmask;
-		snprintf (ifi->v4ad.class_remark, 64, "Nonexistant");
+		safe_snprintf (ifi->v4ad.class_remark, "Nonexistant");
 	}
 
 	/*
-	 * network address (classfull + cidr)
+	 * network address (classful + cidr)
 	 */
 	ifi->v4ad.n_naddr = ifi->v4ad.n_haddr & ifi->v4ad.n_nmask;
 	ifi->v4ad.n_cnaddr = ifi->v4ad.n_haddr & ifi->v4ad.n_cnmask;
@@ -583,7 +583,7 @@ split_ipv6addr (char *addr, struct ipv6_split *spstr)
 	if (split && (count (addr, '/') == 1)) {
 		if (strlen (split) > 1 && strlen (split) < 5) {
 			split++;
-			strncpy (spstr->nmask, split, 3);
+			safe_strncpy (spstr->nmask, split);
 		}
 	}
 
@@ -776,7 +776,7 @@ getcolon (char *addr, int pos, int type)
 			y++;
 		}
 
-		bzero ((char *) str, 5);
+		safe_bzero (str);
 		x = 0;
 		while (y < strlen (addr) && addr[y] != ':') {
 			str[x] = addr[y];
@@ -786,7 +786,7 @@ getcolon (char *addr, int pos, int type)
 	}
 
 	if (compressed) {
-		bzero ((char *) str, 5);
+		safe_bzero (str);
 		if (pos <= cstart) {
 			x = 0;
 			y = 0;
@@ -824,7 +824,7 @@ getcolon (char *addr, int pos, int type)
 				y++;
 			}
 
-			bzero ((char *) str, 5);
+			safe_bzero (str);
 			x = 0;
 			while (y < strlen (addr) && addr[y] != ':') {
 				str[x] = addr[y];
@@ -865,7 +865,7 @@ v6addrtonum (struct ipv6_split spstr, struct v6addr *in6_addr, int type)
 	}
 
 	if (type == V6TYPE_V4INV6) {
-		bzero ((char *) buf, 128);
+		safe_bzero (buf);
 		x = 0;
 		while (spstr.ipv4addr[x] != '.') {
 			buf[x] = spstr.ipv4addr[x];
@@ -883,7 +883,7 @@ v6addrtonum (struct ipv6_split spstr, struct v6addr *in6_addr, int type)
 			}
 			n = atoi (buf);
 
-			bzero ((char *) buf, 128);
+			safe_bzero (buf);
 			z = 0;
 			while (spstr.ipv4addr[x] != '.'
 			       && spstr.ipv4addr[x] != '\0'
@@ -937,9 +937,9 @@ validate_v6addr (char *addr)
 	int x;
 	struct ipv6_split spstr;
 
-	bzero ((char *) spstr.ipv6addr, 40);
-	bzero ((char *) spstr.ipv4addr, 16);
-	bzero ((char *) spstr.nmask, 4);
+	safe_bzero (spstr.ipv6addr);
+	safe_bzero (spstr.ipv4addr);
+	safe_bzero (spstr.nmask);
 
 	split_ipv6addr (addr, &spstr);
 
@@ -1011,29 +1011,29 @@ v6_type (struct v6addr *in6_addr)
 	a = in6_addr->haddr.sip6_addr16[0];
 
 	if (a == 0)
-		snprintf (in6_addr->class_remark, 63, "Reserved");
+		safe_snprintf (in6_addr->class_remark, "Reserved");
 	if (a == 2 || a == 3)
-		snprintf (in6_addr->class_remark, 63,
+		safe_snprintf (in6_addr->class_remark,
 			  "Reserved for NSAP Allocation");
 	if (a == 4 || a == 5)
-		snprintf (in6_addr->class_remark, 63,
+		safe_snprintf (in6_addr->class_remark,
 			  "Reserved for IPX Allocation");
 	if ((a & 0xe000) == 0x2000)
-		snprintf (in6_addr->class_remark, 63,
+		safe_snprintf (in6_addr->class_remark,
 			  "Aggregatable Global Unicast Addresses");
 	if ((a | 0x00ff) == 0x00ff)
-		snprintf (in6_addr->class_remark, 63, "Reserved");
+		safe_snprintf (in6_addr->class_remark, "Reserved");
 	if ((a & 0xff00) == 0xff00)
-		snprintf (in6_addr->class_remark, 63, "Multicast Addresses");
+		safe_snprintf (in6_addr->class_remark, "Multicast Addresses");
 	if ((a & 0xff80) == 0xfe80)
-		snprintf (in6_addr->class_remark, 63,
+		safe_snprintf (in6_addr->class_remark,
 			  "Link-Local Unicast Addresses");
 	if ((a & 0xffc0) == 0xfec0)
-		snprintf (in6_addr->class_remark, 63,
+		safe_snprintf (in6_addr->class_remark,
 			  "Site-Local Unicast Addresses");
 
 	if (in6_addr->class_remark[0] == '\0')
-		snprintf (in6_addr->class_remark, 63, "Unassigned");
+		safe_snprintf (in6_addr->class_remark, "Unassigned");
 
 	return;
 }
@@ -1049,7 +1049,7 @@ v6_comment (struct v6addr *in6_addr)
 			y = 1;
 	}
 	if (!y)
-		snprintf (in6_addr->comment, 63, "Unspecified");
+		safe_snprintf (in6_addr->comment, "Unspecified");
 
 	y = 0;
 	for (x = 0; x < 7; x++) {
@@ -1058,7 +1058,7 @@ v6_comment (struct v6addr *in6_addr)
 	}
 	if (!y)
 		if (in6_addr->haddr.sip6_addr16[7] == 1)
-			snprintf (in6_addr->comment, 63, "Loopback");
+			safe_snprintf (in6_addr->comment, "Loopback");
 
 	return;
 }
@@ -1092,7 +1092,7 @@ get_comp_v6 (struct sip_in6_addr addr)
 	int x, y, z;
 	int start, num;
 
-	bzero ((char *) outad, 44);
+	safe_bzero (outad);
 
 	start = -1;
 	num = 0;
@@ -1121,15 +1121,15 @@ get_comp_v6 (struct sip_in6_addr addr)
 	for (x = 0; x < 8; x++) {
 		if (x == start) {
 			if (!x)
-				strcat (outad, ":");
-			strcat (outad, ":");
+				safe_strncat (outad, ":");
+			safe_strncat (outad, ":");
 			x += num - 1;
 		} else {
-			bzero ((char *) tmpad, 5);
-			sprintf (tmpad, "%x", addr.sip6_addr16[x]);
-			strcat (outad, tmpad);
+			safe_bzero (tmpad);
+			safe_snprintf (tmpad, "%x", addr.sip6_addr16[x]);
+			safe_strncat (outad, tmpad);
 			if (x != 7)
-				strcat (outad, ":");
+				safe_strncat (outad, ":");
 		}
 	}
 
@@ -1142,9 +1142,9 @@ mk_ipv6addr (struct v6addr *in6_addr, char *addr)
 	int x, y, z;
 	struct ipv6_split spstr;
 
-	bzero ((char *) spstr.ipv6addr, 40);
-	bzero ((char *) spstr.ipv4addr, 16);
-	bzero ((char *) spstr.nmask, 4);
+	safe_bzero (spstr.ipv6addr);
+	safe_bzero (spstr.ipv4addr);
+	safe_bzero (spstr.nmask);
 
 	split_ipv6addr (addr, &spstr);
 
@@ -1195,9 +1195,9 @@ mk_ipv6addr (struct v6addr *in6_addr, char *addr)
 	v6addrtobroadcast (in6_addr);
 	in6_addr->real_v4 = v6verifyv4 (in6_addr->haddr);
 
-	bzero ((char *) in6_addr->class_remark, 64);
+	safe_bzero (in6_addr->class_remark);
 	v6_type (in6_addr);
-	bzero ((char *) in6_addr->comment, 64);
+	safe_bzero (in6_addr->comment);
 	v6_comment (in6_addr);
 
 	return 0;
@@ -1209,7 +1209,7 @@ new_dnsresp (struct dnsresp *d_resp)
 	d_resp->next = (struct dnsresp *) malloc (sizeof (struct dnsresp));
 	d_resp = d_resp->next;
 	d_resp->next = NULL;
-	bzero((char *) d_resp->str, 128);
+	safe_bzero(d_resp->str);
 	d_resp->type = 0;
 
 	return d_resp;
@@ -1235,17 +1235,17 @@ _resolv_v4_ghbn (char *raddr, struct dnsresp *d_resp, char *extra)
 	static char retaddr[1024];
 	int x;
 
-	bzero ((char *) retaddr, 1024);
+	safe_bzero (retaddr);
 
 	he = gethostbyname (raddr);
 	if (!he)
 		return NULL;
 
 	if (he->h_addrtype == AF_INET) {
-		snprintf (retaddr, 1023, "%s%s", inet_ntoa (*(struct in_addr *) he->h_addr_list[0]), extra);
+		safe_snprintf (retaddr, "%s%s", inet_ntoa (*(struct in_addr *) he->h_addr_list[0]), extra);
 		x = 0;
 		while (he->h_addr_list[x]) {
-			snprintf (d_resp->str, 127, "%s%s", inet_ntoa (*(struct in_addr *) he->h_addr_list[x]), extra);
+			safe_snprintf (d_resp->str, "%s%s", inet_ntoa (*(struct in_addr *) he->h_addr_list[x]), extra);
 			d_resp->type = AF_INET;
 			x++;
 			if (he->h_addr_list[x])
@@ -1275,18 +1275,18 @@ _resolv_v6_ghbn2 (char *raddr, struct dnsresp *d_resp, char *extra)
 	char ip6addr[128];
 	int x;
 
-	bzero ((char *) retaddr, 1024);
+	safe_bzero (retaddr);
 
 	he = gethostbyname2 (raddr, AF_INET6);
 	if (!he)
 		return NULL;
 
 	if (he->h_addrtype == AF_INET6) {
-		bzero ((char *) ip6addr, 128);
-		snprintf (retaddr, 1023, "%s%s", inet_ntop (AF_INET6, he->h_addr_list[0], ip6addr, 128), extra);
+		safe_bzero (ip6addr);
+		safe_snprintf (retaddr, "%s%s", inet_ntop (AF_INET6, he->h_addr_list[0], ip6addr, 128), extra);
 		x = 0;
 		while (he->h_addr_list[x]) {
-			snprintf (d_resp->str, 127, "%s%s", inet_ntop (AF_INET6, he->h_addr_list[x], ip6addr, 128), extra);
+			safe_snprintf (d_resp->str, "%s%s", inet_ntop (AF_INET6, he->h_addr_list[x], ip6addr, 128), extra);
 			d_resp->type = AF_INET6;
 			x++;
 			if (he->h_addr_list[x])
@@ -1331,11 +1331,11 @@ _resolv_v6_gai (char *raddr, struct dnsresp *d_resp, char *extra)
 
 	res_orig = res;
 	while (res) {
-		bzero ((char *) ip6addr, 128);
+		safe_bzero (ip6addr);
 		if (res->ai_family == PF_INET6) {
 			sin6 = (struct sockaddr_in6 *) res->ai_addr;
-			snprintf (retaddr, 1023, "%s%s", inet_ntop (AF_INET6, &sin6->sin6_addr, ip6addr, 128), extra);
-			snprintf (d_resp->str, 127, "%s%s", inet_ntop (AF_INET6, &sin6->sin6_addr, ip6addr, 128), extra);
+			safe_snprintf (retaddr, "%s%s", inet_ntop (AF_INET6, &sin6->sin6_addr, ip6addr, 128), extra);
+			safe_snprintf (d_resp->str, "%s%s", inet_ntop (AF_INET6, &sin6->sin6_addr, ip6addr, 128), extra);
 			d_resp->type = AF_INET6;
 		}
 		if (res->ai_next && (res->ai_family == PF_INET || res->ai_family == PF_INET6))
@@ -1384,17 +1384,17 @@ _resolv_unspec_gai (char *raddr, struct dnsresp *d_resp, char *extra)
 	res_orig = res;
 
 	while (res) {
-		bzero ((char *) ip6addr, 128);
+		safe_bzero (ip6addr);
 		if (res->ai_family == PF_INET) {
 			sin = (struct sockaddr_in *) res->ai_addr;
-			snprintf (retaddr, 1023, "%s%s", inet_ntoa (sin->sin_addr), extra);
-			snprintf(d_resp->str, 127, "%s%s", inet_ntoa (sin->sin_addr), extra);
+			safe_snprintf (retaddr, "%s%s", inet_ntoa (sin->sin_addr), extra);
+			safe_snprintf(d_resp->str, "%s%s", inet_ntoa (sin->sin_addr), extra);
 			d_resp->type = AF_INET;
 		}
 		if (res->ai_family == PF_INET6) {
 			sin6 = (struct sockaddr_in6 *) res->ai_addr;
-			snprintf (retaddr, 1023, "%s%s", inet_ntop (AF_INET6, &sin6->sin6_addr, ip6addr, 128), extra);
-			snprintf (d_resp->str, 127, "%s%s", inet_ntop (AF_INET6, &sin6->sin6_addr, ip6addr, 128), extra);
+			safe_snprintf (retaddr, "%s%s", inet_ntop (AF_INET6, &sin6->sin6_addr, ip6addr, 128), extra);
+			safe_snprintf (d_resp->str, "%s%s", inet_ntop (AF_INET6, &sin6->sin6_addr, ip6addr, 128), extra);
 			d_resp->type = AF_INET6;
 		}
 		if (res->ai_next && (res->ai_family == PF_INET || res->ai_family == PF_INET6))
@@ -1479,30 +1479,30 @@ resolve_addr (char *addr, int family, struct dnsresp *d_resp)
 	if (family == PF_UNSPEC && !ipv6_cap)
 		family = PF_INET;
 
-	bzero ((char *) extra, 32);
-	bzero ((char *) raddr, 1024);
+	safe_bzero (extra);
+	safe_bzero (raddr);
 	tmpstr = strstr (addr, "/");
 	if (tmpstr) {
-		strncpy (extra, tmpstr, 31);
+		safe_strncpy (extra, tmpstr);
 		strncpy (raddr, addr, strlen (addr) - strlen (tmpstr));
 	}
 	else {
 		tmpstr = strstr (addr, " ");
 		if (tmpstr) {
-			strncpy (extra, tmpstr, 31);
+			safe_strncpy (extra, tmpstr);
 			strncpy (raddr, addr, strlen (addr) - strlen (tmpstr));
 		}
 		else
-			strncpy (raddr, addr, 1023);
+			safe_strncpy (raddr, addr);
 	}
 
-	bzero ((char *) retaddr, 1024);
+	safe_bzero (retaddr);
 
 	if (family == PF_INET) {
 		tmpstr = _resolv_v4_ghbn (raddr, d_resp, extra);
 		if (!tmpstr)
 			return NULL;
-		strncpy (retaddr, tmpstr, 1024);
+		safe_strncpy (retaddr, tmpstr);
 		return retaddr;
 	}
 
@@ -1511,7 +1511,7 @@ resolve_addr (char *addr, int family, struct dnsresp *d_resp)
 			tmpstr = _resolv_v6_gai (raddr, d_resp, extra);
 			if (!tmpstr)
 				return NULL;
-			strncpy (retaddr, tmpstr, 1024);
+			safe_strncpy (retaddr, tmpstr);
 			return retaddr;
 		}
 
@@ -1519,7 +1519,7 @@ resolve_addr (char *addr, int family, struct dnsresp *d_resp)
 			tmpstr = _resolv_v6_ghbn2 (raddr, d_resp, extra);
 			if (!tmpstr)
 				return NULL;
-			strncpy (retaddr, tmpstr, 1024);
+			safe_strncpy (retaddr, tmpstr);
 			return retaddr;
 		}
 	}
@@ -1529,13 +1529,13 @@ resolve_addr (char *addr, int family, struct dnsresp *d_resp)
 			tmpstr = _resolv_unspec_gai (raddr, d_resp, extra);
 			if (!tmpstr)
 				return NULL;
-			strncpy (retaddr, tmpstr, 1024);
+			safe_strncpy (retaddr, tmpstr);
 			return retaddr;
 		}
 		if (f_gethostbyname && f_gethostbyname2) {
 			tmpstr = _resolv_v4_ghbn (raddr, d_resp, extra);
 			if (tmpstr) {
-				strncpy (retaddr, tmpstr, 1024);
+				safe_strncpy (retaddr, tmpstr);
 				d_resp_tmp = d_resp;
 				d_resp = new_dnsresp (d_resp);
 			}
